/* or1k-asm.h -- OR1K assembly helper macros

   Copyright (c) 2014 OpenRISC Project Maintainers
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following condition
   is met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
   INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
   STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
   OF THE POSSIBILITY OF SUCH DAMAGE.
   */

#ifndef __OR1K_NOP_H__
#define __OR1K_NOP_H__

#define OR1K_NOP_K_NOP		0x0
#define OR1K_NOP_K_EXIT		0x1
#define OR1K_NOP_K_PUTC		0x4
#define OR1K_NOP_K_EXIT_QUIET	0xc

#endif
